/*
 * Copyright 2022-2025 Nico Sonack <nsonack@herrhotzenplotz.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GITEA_LABELS_H
#define GITEA_LABELS_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gcli/labels.h>
#include <gcli/path.h>

int gitea_get_label(struct gcli_ctx *ctx, struct gcli_path const *path,
                    struct gcli_label *out);

int gitea_get_labels(struct gcli_ctx *ctx, struct gcli_path const *path,
                     int max, struct gcli_label_list *out);

int gitea_create_label(struct gcli_ctx *ctx, struct gcli_path const *path,
                       struct gcli_label *label);

int gitea_delete_label(struct gcli_ctx *ctx, struct gcli_path const *repo_path);

int gitea_label_set_title(struct gcli_ctx *ctx, struct gcli_path const *path,
                          char const *new_name);

int gitea_label_set_description(struct gcli_ctx *ctx,
                                struct gcli_path const *const path,
                                char const *const description);

int gitea_label_set_colour(struct gcli_ctx *ctx, struct gcli_path const *path,
                           uint32_t colour);

#endif /* GITEA_LABELS_H */
